# Community

> Learn about the OpenHands community, mission, and values

# The OpenHands Community

OpenHands is a community of engineers, academics, and enthusiasts reimagining software development for an AI-powered world.

## Mission

It's very clear that AI is changing software development. We want the developer community to drive that change organically, through open source.

So we're not just building friendly interfaces for AI-driven development. We're publishing *building blocks* that empower developers to create new experiences, tailored to your own habits, needs, and imagination.

## Ethos

We have two core values: **high openness** and **high agency**. While we don't expect everyone in the community to embody these values, we want to establish them as norms.

### High Openness

We welcome anyone and everyone into our community by default. You don't have to be a software developer to help us build. You don't have to be pro-AI to help us learn.

Our plans, our work, our successes, and our failures are all public record. We want the world to see not just the fruits of our work, but the whole process of growing it.

We welcome thoughtful criticism, whether it's a comment on a PR or feedback on the community as a whole.

### High Agency

Everyone should feel empowered to contribute to OpenHands. Whether it's by making a PR, hosting an event, sharing feedback, or just asking a question, don't hold back!

OpenHands gives everyone the building blocks to create state-of-the-art developer experiences. We experiment constantly and love building new things.

Coding, development practices, and communities are changing rapidly. We won't hesitate to change direction and make big bets.

## Relationship to All Hands

OpenHands is supported by the for-profit organization [All Hands AI, Inc](https://www.all-hands.dev/).

All Hands was founded by three of the first major contributors to OpenHands:

* Xingyao Wang, a UIUC PhD candidate who got OpenHands to the top of the SWE-bench leaderboards
* Graham Neubig, a CMU Professor who rallied the academic community around OpenHands
* Robert Brennan, a software engineer who architected the user-facing features of OpenHands

All Hands is an important part of the OpenHands ecosystem. We've raised over \$20M—mainly to hire developers and researchers who can work on OpenHands full-time, and to provide them with expensive infrastructure. ([Join us!](https://allhandsai.applytojob.com/apply/))

But we see OpenHands as much larger, and ultimately more important, than All Hands. When our financial responsibility to investors is at odds with our social responsibility to the community—as it inevitably will be, from time to time—we promise to navigate that conflict thoughtfully and transparently.

At some point, we may transfer custody of OpenHands to an open source foundation. But for now, the [Benevolent Dictator approach](http://www.catb.org/~esr/writings/cathedral-bazaar/homesteading/ar01s16.html) helps us move forward with speed and intention. If we ever forget the "benevolent" part, please: fork us.


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt